﻿Imports System
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Input
Imports System.Windows.Shapes

Namespace SimpleDraw

    ' <summary>
    ' Interaction logic for MainWindow.xaml
    ' </summary>
    Partial Public Class MainWindow
        Inherits Window

        Private Enum ShapeTypeEnum
            Line
            Oval
            Rectangle
        End Enum

        Private startPoint As Point
        Private endPoint As Point
        Private shapeType As ShapeTypeEnum = ShapeTypeEnum.Line

        Public Sub New()

            InitializeComponent()
        End Sub


        Private Sub canvas1_MouseDown(sender As Object,
                e As MouseButtonEventArgs)

            startPoint = e.GetPosition(Me)
        End Sub

        Private Sub canvas1_MouseUp(sender As Object,
                e As MouseButtonEventArgs)

            endPoint = e.GetPosition(Me)
            Dim shape As IShape = Nothing
            If (shapeType = ShapeTypeEnum.Line) Then
                shape = New SimpleLine(startPoint.X, startPoint.Y,
                        endPoint.X, endPoint.Y)
            ElseIf (shapeType = ShapeTypeEnum.Oval) Then
                shape = New SimpleOval(startPoint.X, startPoint.Y,
                        endPoint.X, endPoint.Y)
            ElseIf (shapeType = ShapeTypeEnum.Rectangle) Then
                shape = New SimpleRectangle(startPoint.X,
                        startPoint.Y, endPoint.X, endPoint.Y)
            End If

            If (Not IsNothing(shape)) Then
                Dim grid As Grid = CType(Me.FindName("buttonGrid"), Grid)
                shape.Draw(grid)
            End If
        End Sub

        Private Sub radioButton1_Checked(sender As Object,
                e As RoutedEventArgs)
            shapeType = ShapeTypeEnum.Line
        End Sub

        Private Sub radioButton2_Checked(sender As Object,
                e As RoutedEventArgs)
            shapeType = ShapeTypeEnum.Oval
        End Sub

        Private Sub radioButton3_Checked(sender As Object,
                e As RoutedEventArgs)
            shapeType = ShapeTypeEnum.Rectangle
        End Sub
    End Class


    Interface IShape
        Sub Draw(myGrid As Grid)
    End Interface

    Public Class SimpleLine
        Implements IShape

        Dim x1, y1, x2, y2 As Double

        Public Sub New(x1 As Double, y1 As Double, x2 As Double,
                y2 As Double)

            Me.x1 = x1
            Me.y1 = y1
            Me.x2 = x2
            Me.y2 = y2
        End Sub

        Public Sub Draw(grid As Grid) Implements IShape.Draw

            Dim windowLine = New Line()
            windowLine.X1 = x1
            windowLine.Y1 = y1
            windowLine.X2 = x2
            windowLine.Y2 = y2
            windowLine.Stroke =
                    System.Windows.Media.Brushes.Magenta
            windowLine.StrokeThickness = 2
            grid.Children.Add(windowLine)
        End Sub
    End Class

    Public Class SimpleOval
        Implements IShape

        Dim x1, y1, x2, y2 As Double

        Public Sub New(x1 As Double, y1 As Double, x2 As Double,
                y2 As Double)

            Me.x1 = x1
            Me.y1 = y1
            Me.x2 = x2
            Me.y2 = y2
        End Sub

        Public Sub Draw(grid As Grid) Implements IShape.Draw

            Dim x, y As Double
            Dim oval = New Ellipse()
            Dim margin As Thickness

            If (x1 < x2) Then
                x = x1
            Else
                x = x2
            End If

            If (y1 < y2) Then
                y = y1
            Else
                y = y2
            End If

            margin = New Thickness(x, y, 0, 0)
            oval.Margin = margin
            oval.HorizontalAlignment = HorizontalAlignment.Left
            oval.VerticalAlignment = VerticalAlignment.Top
            oval.Stroke = System.Windows.Media.Brushes.LimeGreen
            oval.Width = Math.Abs(x2 - x1)
            oval.Height = Math.Abs(y2 - y1)
            Canvas.SetLeft(oval, x)
            Canvas.SetTop(oval, y)
            oval.StrokeThickness = 2
            grid.Children.Add(oval)
        End Sub
    End Class

    Public Class SimpleRectangle
        Implements IShape

        Dim x1, y1, x2, y2 As Double

        Public Sub New(x1 As Double, y1 As Double, x2 As Double,
                y2 As Double)

            Me.x1 = x1
            Me.y1 = y1
            Me.x2 = x2
            Me.y2 = y2
        End Sub

        Public Sub Draw(grid As Grid) Implements IShape.Draw

            Dim x, y As Double
            Dim Rect = New Rectangle()
            If (x1 < x2) Then
                x = x1
            Else
                x = x2
            End If

            If (y1 < y2) Then
                y = y1
            Else
                y = y2
            End If

            Dim margin = New Thickness(x, y, 0, 0)
            Rect.Margin = margin
            Rect.HorizontalAlignment = HorizontalAlignment.Left
            Rect.VerticalAlignment = VerticalAlignment.Top
            Rect.Stroke = System.Windows.Media.Brushes.Red
            Rect.Width = Math.Abs(x2 - x1)
            Rect.Height = Math.Abs(y2 - y1)
            Canvas.SetLeft(Rect, x)
            Canvas.SetTop(Rect, y)
            Rect.StrokeThickness = 2
            grid.Children.Add(Rect)

        End Sub
    End Class
End Namespace